@@ -35,8 +35,8 @@ static void gdaui_entry_wrapper_get_property (GObject *object,
 					      GValue *value,
 					      GParamSpec *pspec);
 
-static void contents_changed_cb (GtkWidget *entry, GdauiEntryWrapper *wrapper);
-static void contents_activated_cb (GtkWidget *entry, GdauiEntryWrapper *wrapper);
+static void contents_changed_cb (GtkWidget *entry, GdauiEntryWrapper *mgwrap);
+static void contents_activated_cb (GtkWidget *entry, GdauiEntryWrapper *mgwrap);
 static void check_correct_init (GdauiEntryWrapper *wid);
 static void block_signals (GdauiEntryWrapper *wid);
 static void unblock_signals (GdauiEntryWrapper *wid);
@@ -57,8 +57,6 @@ static gboolean        gdaui_entry_wrapper_can_expand        (GdauiDataEntry *de
 static void            gdaui_entry_wrapper_set_editable      (GdauiDataEntry *de, gboolean editable);
 static gboolean        gdaui_entry_wrapper_get_editable      (GdauiDataEntry *de);
 static void            gdaui_entry_wrapper_grab_focus        (GdauiDataEntry *de);
-static void            gdaui_entry_wrapper_set_unknown_color (GdauiDataEntry *de, gdouble red, gdouble green,
-							      gdouble blue, gdouble alpha);
 
 /* properties */
 enum {
@@ -140,7 +138,6 @@ gdaui_entry_wrapper_data_entry_init (GdauiDataEntryIface *iface)
 	iface->set_editable = gdaui_entry_wrapper_set_editable;
 	iface->get_editable = gdaui_entry_wrapper_get_editable;
 	iface->grab_focus = gdaui_entry_wrapper_grab_focus;
-	iface->set_unknown_color = gdaui_entry_wrapper_set_unknown_color;
 }
 
 
@@ -167,50 +164,50 @@ gdaui_entry_wrapper_class_init (GdauiEntryWrapperClass *klass)
 }
 
 static void
-check_correct_init (GdauiEntryWrapper *wrapper)
+check_correct_init (GdauiEntryWrapper *mgwrap)
 {
-	if (!wrapper->priv->impl_is_correct) {
+	if (!mgwrap->priv->impl_is_correct) {
 		GtkWidget *entry = NULL;
 		GdauiEntryWrapperClass *klass;
 		gboolean class_impl_error = FALSE;;
 
-		klass = GDAUI_ENTRY_WRAPPER_CLASS (G_OBJECT_GET_CLASS (wrapper));
+		klass = GDAUI_ENTRY_WRAPPER_CLASS (G_OBJECT_GET_CLASS (mgwrap));
 		if (! klass->create_entry) {
 			g_warning ("create_entry () virtual function not implemented for object class %s\n",
-				   G_OBJECT_TYPE_NAME (wrapper));
+				   G_OBJECT_TYPE_NAME (mgwrap));
 			class_impl_error = TRUE;
 		}
 		if (! klass->real_set_value) {
 			g_warning ("real_set_value () virtual function not implemented for object class %s\n",
-				   G_OBJECT_TYPE_NAME (wrapper));
+				   G_OBJECT_TYPE_NAME (mgwrap));
 			class_impl_error = TRUE;
 		}
 		if (! klass->real_get_value) {
 			g_warning ("real_get_value () virtual function not implemented for object class %s\n",
-				   G_OBJECT_TYPE_NAME (wrapper));
+				   G_OBJECT_TYPE_NAME (mgwrap));
 			class_impl_error = TRUE;
 		}
 		if (! klass->connect_signals) {
 			g_warning ("connect_signals () virtual function not implemented for object class %s\n",
-				   G_OBJECT_TYPE_NAME (wrapper));
+				   G_OBJECT_TYPE_NAME (mgwrap));
 			class_impl_error = TRUE;
 		}
 		if (! klass->can_expand) {
 			g_warning ("can_expand () virtual function not implemented for object class %s\n",
-				   G_OBJECT_TYPE_NAME (wrapper));
+				   G_OBJECT_TYPE_NAME (mgwrap));
 			class_impl_error = TRUE;
 		}
 
 		if (!class_impl_error) {
-			wrapper->priv->real_class = klass;
-			wrapper->priv->impl_is_correct = TRUE;
-			entry = (*wrapper->priv->real_class->create_entry) (wrapper);
+			mgwrap->priv->real_class = klass;
+			mgwrap->priv->impl_is_correct = TRUE;
+			entry = (*mgwrap->priv->real_class->create_entry) (mgwrap);
 
-			gdaui_entry_shell_pack_entry (GDAUI_ENTRY_SHELL (wrapper), entry);
+			gdaui_entry_shell_pack_entry (GDAUI_ENTRY_SHELL (mgwrap), entry);
 			gtk_widget_show (entry);
-			wrapper->priv->entry = entry;
+			mgwrap->priv->entry = entry;
 
-			(*wrapper->priv->real_class->connect_signals) (wrapper, G_CALLBACK (contents_changed_cb),
+			(*mgwrap->priv->real_class->connect_signals) (mgwrap, G_CALLBACK (contents_changed_cb),
 								      G_CALLBACK (contents_activated_cb));
 		}
 		else {
@@ -221,62 +218,62 @@ check_correct_init (GdauiEntryWrapper *wrapper)
 }
 
 static void
-block_signals (GdauiEntryWrapper *wrapper)
+block_signals (GdauiEntryWrapper *mgwrap)
 {
-	wrapper->priv->signals_blocked ++;
+	mgwrap->priv->signals_blocked ++;
 }
 
 static void
-unblock_signals (GdauiEntryWrapper *wrapper)
+unblock_signals (GdauiEntryWrapper *mgwrap)
 {
-	wrapper->priv->signals_blocked --;
+	mgwrap->priv->signals_blocked --;
 }
 
 
 static void
-gdaui_entry_wrapper_init (GdauiEntryWrapper *wrapper)
+gdaui_entry_wrapper_init (GdauiEntryWrapper *mgwrap)
 {
 	/* Private structure */
-	wrapper->priv = g_new0 (GdauiEntryWrapperPriv, 1);
-	wrapper->priv->impl_is_correct = FALSE;
-	wrapper->priv->entry = NULL;
-	wrapper->priv->real_class = NULL;
-	wrapper->priv->signals_blocked = 0;
+	mgwrap->priv = g_new0 (GdauiEntryWrapperPriv, 1);
+	mgwrap->priv->impl_is_correct = FALSE;
+	mgwrap->priv->entry = NULL;
+	mgwrap->priv->real_class = NULL;
+	mgwrap->priv->signals_blocked = 0;
 
-	wrapper->priv->type = GDA_TYPE_NULL;
-	wrapper->priv->value_ref = NULL;
-	wrapper->priv->value_default = NULL;
+	mgwrap->priv->type = GDA_TYPE_NULL;
+	mgwrap->priv->value_ref = NULL;
+	mgwrap->priv->value_default = NULL;
 
-	wrapper->priv->null_forced = FALSE;
-	wrapper->priv->default_forced = FALSE;
+	mgwrap->priv->null_forced = FALSE;
+	mgwrap->priv->default_forced = FALSE;
 
-	wrapper->priv->null_possible = TRUE;
-	wrapper->priv->default_possible = FALSE;
-	wrapper->priv->show_actions = TRUE;
-	wrapper->priv->editable = TRUE;
-	wrapper->priv->contents_has_changed = FALSE;
+	mgwrap->priv->null_possible = TRUE;
+	mgwrap->priv->default_possible = FALSE;
+	mgwrap->priv->show_actions = TRUE;
+	mgwrap->priv->editable = TRUE;
+	mgwrap->priv->contents_has_changed = FALSE;
 
-	wrapper->priv->set_default_if_invalid = FALSE;
+	mgwrap->priv->set_default_if_invalid = FALSE;
 }
 
 static void
 gdaui_entry_wrapper_dispose (GObject *object)
 {
-	GdauiEntryWrapper *wrapper;
+	GdauiEntryWrapper *mgwrap;
 
 	g_return_if_fail (object != NULL);
 	g_return_if_fail (GDAUI_IS_ENTRY_WRAPPER (object));
 
-	wrapper = GDAUI_ENTRY_WRAPPER (object);
+	mgwrap = GDAUI_ENTRY_WRAPPER (object);
 
-	if (wrapper->priv) {
-		if (wrapper->priv->value_ref)
-			gda_value_free (wrapper->priv->value_ref);
-		if (wrapper->priv->value_default)
-			gda_value_free (wrapper->priv->value_default);
+	if (mgwrap->priv) {
+		if (mgwrap->priv->value_ref)
+			gda_value_free (mgwrap->priv->value_ref);
+		if (mgwrap->priv->value_default)
+			gda_value_free (mgwrap->priv->value_default);
 
-		g_free (wrapper->priv);
-		wrapper->priv = NULL;
+		g_free (mgwrap->priv);
+		mgwrap->priv = NULL;
 	}
 
 	/* for the parent class */
@@ -290,25 +287,25 @@ gdaui_entry_wrapper_set_property (GObject *object,
 				  const GValue *value,
 				  GParamSpec *pspec)
 {
-	GdauiEntryWrapper *wrapper = GDAUI_ENTRY_WRAPPER (object);
-	if (wrapper->priv) {
+	GdauiEntryWrapper *mgwrap = GDAUI_ENTRY_WRAPPER (object);
+	if (mgwrap->priv) {
 		switch (param_id) {
 		case PROP_SET_DEFAULT_IF_INVALID: {
 			guint attrs;
 
-			wrapper->priv->set_default_if_invalid = g_value_get_boolean (value);
-			attrs = gdaui_data_entry_get_attributes (GDAUI_DATA_ENTRY (wrapper));
+			mgwrap->priv->set_default_if_invalid = g_value_get_boolean (value);
+			attrs = gdaui_data_entry_get_attributes (GDAUI_DATA_ENTRY (mgwrap));
 
-			if (wrapper->priv->set_default_if_invalid && (attrs & GDA_VALUE_ATTR_DATA_NON_VALID)) {
+			if (mgwrap->priv->set_default_if_invalid && (attrs & GDA_VALUE_ATTR_DATA_NON_VALID)) {
 				GValue *sane_value;
 				GdaDataHandler *dh;
 				GType type;
 
-				check_correct_init (wrapper);
-				dh = gdaui_data_entry_get_handler (GDAUI_DATA_ENTRY (wrapper));
-				type = gdaui_data_entry_get_value_type (GDAUI_DATA_ENTRY (wrapper));
+				check_correct_init (mgwrap);
+				dh = gdaui_data_entry_get_handler (GDAUI_DATA_ENTRY (mgwrap));
+				type = gdaui_data_entry_get_value_type (GDAUI_DATA_ENTRY (mgwrap));
 				sane_value = gda_data_handler_get_sane_init_value (dh, type);
-				(*wrapper->priv->real_class->real_set_value) (wrapper, sane_value);
+				(*mgwrap->priv->real_class->real_set_value) (mgwrap, sane_value);
 				if (sane_value)
 					gda_value_free (sane_value);
 			}
@@ -327,11 +324,11 @@ gdaui_entry_wrapper_get_property (GObject *object,
 				  GValue *value,
 				  GParamSpec *pspec)
 {
-	GdauiEntryWrapper *wrapper = GDAUI_ENTRY_WRAPPER (object);
-	if (wrapper->priv) {
+	GdauiEntryWrapper *mgwrap = GDAUI_ENTRY_WRAPPER (object);
+	if (mgwrap->priv) {
 		switch (param_id) {
 		case PROP_SET_DEFAULT_IF_INVALID:
-			g_value_set_boolean (value, wrapper->priv->set_default_if_invalid);
+			g_value_set_boolean (value, mgwrap->priv->set_default_if_invalid);
 			break;
 		default:
 			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
@@ -342,58 +339,58 @@ gdaui_entry_wrapper_get_property (GObject *object,
 
 /**
  * gdaui_entry_wrapper_contents_changed:
- * @wrapper: a #GdauiEntryWrapper widget
+ * @mgwrap: a #GdauiEntryWrapper widget
  *
  * Signals to @gwrap that the entry has changed
  */
 void
-gdaui_entry_wrapper_contents_changed (GdauiEntryWrapper *wrapper)
+gdaui_entry_wrapper_contents_changed (GdauiEntryWrapper *mgwrap)
 {
-	g_return_if_fail (GDAUI_IS_ENTRY_WRAPPER (wrapper));
+	g_return_if_fail (GDAUI_IS_ENTRY_WRAPPER (mgwrap));
 
-	contents_changed_cb (NULL, wrapper);
+	contents_changed_cb (NULL, mgwrap);
 }
 
 /**
  * gdaui_entry_wrapper_contents_activated:
- * @wrapper: a #GdauiEntryWrapper widget
+ * @mgwrap: a #GdauiEntryWrapper widget
  *
  * Signals to @gwrap that the entry has been activated (that is the user
  * pressed ENTER for example to signify he has finished entering data)
  */
 void
-gdaui_entry_wrapper_contents_activated (GdauiEntryWrapper *wrapper)
+gdaui_entry_wrapper_contents_activated (GdauiEntryWrapper *mgwrap)
 {
-	g_return_if_fail (GDAUI_IS_ENTRY_WRAPPER (wrapper));
+	g_return_if_fail (GDAUI_IS_ENTRY_WRAPPER (mgwrap));
 
-	contents_activated_cb (NULL, wrapper);
+	contents_activated_cb (NULL, mgwrap);
 }
 
 
-static void gdaui_entry_wrapper_emit_signal (GdauiEntryWrapper *wrapper);
+static void gdaui_entry_wrapper_emit_signal (GdauiEntryWrapper *mgwrap);
 static void
-contents_changed_cb (G_GNUC_UNUSED GtkWidget *entry, GdauiEntryWrapper *wrapper)
+contents_changed_cb (G_GNUC_UNUSED GtkWidget *entry, GdauiEntryWrapper *mgwrap)
 {
 	/* @entry is not used */
-	if (! wrapper->priv->signals_blocked) {
-		wrapper->priv->null_forced = FALSE;
-		wrapper->priv->default_forced = FALSE;
-		wrapper->priv->contents_has_changed = TRUE;
-		gdaui_entry_wrapper_emit_signal (wrapper);
+	if (! mgwrap->priv->signals_blocked) {
+		mgwrap->priv->null_forced = FALSE;
+		mgwrap->priv->default_forced = FALSE;
+		mgwrap->priv->contents_has_changed = TRUE;
+		gdaui_entry_wrapper_emit_signal (mgwrap);
 	}
 }
 
 static void
-contents_activated_cb (G_GNUC_UNUSED GtkWidget *entry, GdauiEntryWrapper *wrapper)
+contents_activated_cb (G_GNUC_UNUSED GtkWidget *entry, GdauiEntryWrapper *mgwrap)
 {
 	/* @entry is not used */
-	if (! wrapper->priv->signals_blocked) {
-		wrapper->priv->null_forced = FALSE;
-		wrapper->priv->default_forced = FALSE;
+	if (! mgwrap->priv->signals_blocked) {
+		mgwrap->priv->null_forced = FALSE;
+		mgwrap->priv->default_forced = FALSE;
 #ifdef debug_signal
 		g_print (">> 'CONTENTS_ACTIVATED' from %s\n", __FUNCTION__);
 #endif
-		g_signal_emit_by_name (G_OBJECT (wrapper), "contents-activated");
+		g_signal_emit_by_name (G_OBJECT (mgwrap), "contents-activated");
 #ifdef debug_signal
 		g_print ("<< 'CONTENTS_ACTIVATED' from %s\n", __FUNCTION__);
 #endif
@@ -401,13 +398,13 @@ contents_activated_cb (G_GNUC_UNUSED GtkWidget *entry, GdauiEntryWrapper *wrappe
 }
 
 static void
-gdaui_entry_wrapper_emit_signal (GdauiEntryWrapper *wrapper)
+gdaui_entry_wrapper_emit_signal (GdauiEntryWrapper *mgwrap)
 {
-	if (! wrapper->priv->signals_blocked) {
+	if (! mgwrap->priv->signals_blocked) {
 #ifdef debug_signal
 		g_print (">> 'CONTENTS_MODIFIED' from %s\n", __FUNCTION__);
 #endif
-		g_signal_emit_by_name (G_OBJECT (wrapper), "contents-modified");
+		g_signal_emit_by_name (G_OBJECT (mgwrap), "contents-modified");
 #ifdef debug_signal
 		g_print ("<< 'CONTENTS_MODIFIED' from %s\n", __FUNCTION__);
 #endif
@@ -420,29 +417,29 @@ gdaui_entry_wrapper_emit_signal (GdauiEntryWrapper *wrapper)
 static void
 gdaui_entry_wrapper_set_value_type (GdauiDataEntry *iface, GType type)
 {
-	GdauiEntryWrapper *wrapper;
+	GdauiEntryWrapper *mgwrap;
 
 	g_return_if_fail (GDAUI_IS_ENTRY_WRAPPER (iface));
-	wrapper = (GdauiEntryWrapper*) iface;
+	mgwrap = (GdauiEntryWrapper*) iface;
 
-	if (wrapper->priv->type != type) {
+	if (mgwrap->priv->type != type) {
 		GValue *value;
 
-		if (wrapper->priv->value_ref) {
-			gda_value_free (wrapper->priv->value_ref);
-			wrapper->priv->value_ref = NULL;
+		if (mgwrap->priv->value_ref) {
+			gda_value_free (mgwrap->priv->value_ref);
+			mgwrap->priv->value_ref = NULL;
 		}
-		if (wrapper->priv->value_default) {
-			gda_value_free (wrapper->priv->value_default);
-			wrapper->priv->value_default = NULL;
+		if (mgwrap->priv->value_default) {
+			gda_value_free (mgwrap->priv->value_default);
+			mgwrap->priv->value_default = NULL;
 		}
 
-		wrapper->priv->type = type;
-		wrapper->priv->value_default = gda_value_new_null ();
+		mgwrap->priv->type = type;
+		mgwrap->priv->value_default = gda_value_new_null ();
 
 		/* Set original value */
 		value = gda_value_new_null ();
-		gdaui_entry_wrapper_set_ref_value (GDAUI_DATA_ENTRY (wrapper), value);
+		gdaui_entry_wrapper_set_ref_value (GDAUI_DATA_ENTRY (mgwrap), value);
  		gda_value_free (value);
 	}
 }
@@ -450,66 +447,66 @@ gdaui_entry_wrapper_set_value_type (GdauiDataEntry *iface, GType type)
 static GType
 gdaui_entry_wrapper_get_value_type (GdauiDataEntry *iface)
 {
-	GdauiEntryWrapper *wrapper;
+	GdauiEntryWrapper *mgwrap;
 
 	g_return_val_if_fail (GDAUI_IS_ENTRY_WRAPPER (iface), G_TYPE_INVALID);
-	wrapper = (GdauiEntryWrapper*) iface;
+	mgwrap = (GdauiEntryWrapper*) iface;
 
-	return wrapper->priv->type;
+	return mgwrap->priv->type;
 }
 
 
 static void
 gdaui_entry_wrapper_set_value (GdauiDataEntry *iface, const GValue *value)
 {
-	GdauiEntryWrapper *wrapper;
+	GdauiEntryWrapper *mgwrap;
 
 	g_return_if_fail (GDAUI_IS_ENTRY_WRAPPER (iface));
-	wrapper = (GdauiEntryWrapper*) iface;
-	check_correct_init (wrapper);
+	mgwrap = (GdauiEntryWrapper*) iface;
+	check_correct_init (mgwrap);
 
-	block_signals (wrapper);
+	block_signals (mgwrap);
 	if (value) {
-		g_return_if_fail ((G_VALUE_TYPE ((GValue *) value) == wrapper->priv->type) ||
+		g_return_if_fail ((G_VALUE_TYPE ((GValue *) value) == mgwrap->priv->type) ||
 				  (G_VALUE_TYPE ((GValue *) value) == GDA_TYPE_NULL));
-		(*wrapper->priv->real_class->real_set_value) (wrapper, value);
+		(*mgwrap->priv->real_class->real_set_value) (mgwrap, value);
 		if (G_VALUE_TYPE ((GValue *) value) == GDA_TYPE_NULL)
-			wrapper->priv->null_forced = TRUE;
+			mgwrap->priv->null_forced = TRUE;
 		else
-			wrapper->priv->null_forced = FALSE;
+			mgwrap->priv->null_forced = FALSE;
 	}
 	else {
-		(*wrapper->priv->real_class->real_set_value) (wrapper, NULL);
-		wrapper->priv->null_forced = TRUE;
+		(*mgwrap->priv->real_class->real_set_value) (mgwrap, NULL);
+		mgwrap->priv->null_forced = TRUE;
 	}
-	unblock_signals (wrapper);
-	wrapper->priv->default_forced = FALSE;
-	wrapper->priv->contents_has_changed = FALSE;
+	unblock_signals (mgwrap);
+	mgwrap->priv->default_forced = FALSE;
+	mgwrap->priv->contents_has_changed = FALSE;
 
-	gdaui_entry_wrapper_emit_signal (wrapper);
+	gdaui_entry_wrapper_emit_signal (mgwrap);
 }
 
 static GValue *
 gdaui_entry_wrapper_get_value (GdauiDataEntry *iface)
 {
 	GValue *value = NULL;
-	GdauiEntryWrapper *wrapper;
+	GdauiEntryWrapper *mgwrap;
 
 	g_return_val_if_fail (GDAUI_IS_ENTRY_WRAPPER (iface), NULL);
-	wrapper = (GdauiEntryWrapper*) iface;
+	mgwrap = (GdauiEntryWrapper*) iface;
 
-	if (wrapper->priv->null_forced)
+	if (mgwrap->priv->null_forced)
 		value = gda_value_new_null ();
 	else {
-		if (wrapper->priv->default_forced) {
-			if (G_VALUE_TYPE (wrapper->priv->value_default) == wrapper->priv->type)
-				value = gda_value_copy (wrapper->priv->value_default);
+		if (mgwrap->priv->default_forced) {
+			if (G_VALUE_TYPE (mgwrap->priv->value_default) == mgwrap->priv->type)
+				value = gda_value_copy (mgwrap->priv->value_default);
 			else
 				value = gda_value_new_null ();
 		}
 		else {
-			check_correct_init (wrapper);
-			value = (wrapper->priv->real_class->real_get_value) (wrapper);
+			check_correct_init (mgwrap);
+			value = (mgwrap->priv->real_class->real_get_value) (mgwrap);
 		}
 	}
 
@@ -519,17 +516,17 @@ gdaui_entry_wrapper_get_value (GdauiDataEntry *iface)
 static void
 gdaui_entry_wrapper_set_ref_value (GdauiDataEntry *iface, const GValue *value)
 {
-	GdauiEntryWrapper *wrapper;
+	GdauiEntryWrapper *mgwrap;
 	gboolean changed = TRUE;
 	GValue *evalue;
 
 	g_return_if_fail (GDAUI_IS_ENTRY_WRAPPER (iface));
-	wrapper = (GdauiEntryWrapper*) iface;
-	check_correct_init (wrapper);
+	mgwrap = (GdauiEntryWrapper*) iface;
+	check_correct_init (mgwrap);
 
 	/* compare existing value and the one provided as argument */
-	if (wrapper->priv->real_class->value_is_equal_to)
-		changed = ! wrapper->priv->real_class->value_is_equal_to (wrapper, value);
+	if (mgwrap->priv->real_class->value_is_equal_to)
+		changed = ! mgwrap->priv->real_class->value_is_equal_to (mgwrap, value);
 	else {
 		evalue = gdaui_entry_wrapper_get_value (iface);
 		if ((!value || (G_VALUE_TYPE (value) == GDA_TYPE_NULL)) &&
@@ -542,29 +539,29 @@ gdaui_entry_wrapper_set_ref_value (GdauiDataEntry *iface, const GValue *value)
 	}
 
 	/* get rid on any existing orig value */
-	if (wrapper->priv->value_ref) {
-		gda_value_free (wrapper->priv->value_ref);
-		wrapper->priv->value_ref = NULL;
+	if (mgwrap->priv->value_ref) {
+		gda_value_free (mgwrap->priv->value_ref);
+		mgwrap->priv->value_ref = NULL;
 	}
 
 	/* apply changes, if any */
 	if (changed) {
-		block_signals (wrapper);
+		block_signals (mgwrap);
 		gdaui_entry_wrapper_set_value (iface, value);
-		unblock_signals (wrapper);
+		unblock_signals (mgwrap);
 	}
 
 	if (value) {
-		g_return_if_fail ((G_VALUE_TYPE ((GValue *) value) == wrapper->priv->type) ||
+		g_return_if_fail ((G_VALUE_TYPE ((GValue *) value) == mgwrap->priv->type) ||
 				  (G_VALUE_TYPE ((GValue *) value) == GDA_TYPE_NULL));
-		wrapper->priv->value_ref = gda_value_copy ((GValue *) value);
+		mgwrap->priv->value_ref = gda_value_copy ((GValue *) value);
 	}
 	else
-		wrapper->priv->value_ref = gda_value_new_null ();
+		mgwrap->priv->value_ref = gda_value_new_null ();
 
 	/* signal changes if any */
 	if (changed)
-		gdaui_entry_wrapper_emit_signal (wrapper);
+		gdaui_entry_wrapper_emit_signal (mgwrap);
 }
 
 static const GValue *
@@ -579,32 +576,32 @@ gdaui_entry_wrapper_get_ref_value (GdauiDataEntry *iface)
 static void
 gdaui_entry_wrapper_set_value_default (GdauiDataEntry *iface, const GValue *value)
 {
-	GdauiEntryWrapper *wrapper;
+	GdauiEntryWrapper *mgwrap;
 
 	g_return_if_fail (GDAUI_IS_ENTRY_WRAPPER (iface));
-	wrapper = (GdauiEntryWrapper*) iface;
+	mgwrap = (GdauiEntryWrapper*) iface;
 
-	if (wrapper->priv->value_default)
-		gda_value_free (wrapper->priv->value_default);
+	if (mgwrap->priv->value_default)
+		gda_value_free (mgwrap->priv->value_default);
 
 	if (value)
-		wrapper->priv->value_default = gda_value_copy ((GValue *) value);
+		mgwrap->priv->value_default = gda_value_copy ((GValue *) value);
 	else
-		wrapper->priv->value_default = gda_value_new_null ();
+		mgwrap->priv->value_default = gda_value_new_null ();
 
-	if (wrapper->priv->default_forced) {
-		if (G_VALUE_TYPE (wrapper->priv->value_default) == wrapper->priv->type) {
-			check_correct_init (wrapper);
-			block_signals (wrapper);
-			gdaui_entry_wrapper_set_value (iface, wrapper->priv->value_default);
-			unblock_signals (wrapper);
-			wrapper->priv->default_forced = TRUE;
-			gdaui_entry_wrapper_emit_signal (wrapper);
+	if (mgwrap->priv->default_forced) {
+		if (G_VALUE_TYPE (mgwrap->priv->value_default) == mgwrap->priv->type) {
+			check_correct_init (mgwrap);
+			block_signals (mgwrap);
+			gdaui_entry_wrapper_set_value (iface, mgwrap->priv->value_default);
+			unblock_signals (mgwrap);
+			mgwrap->priv->default_forced = TRUE;
+			gdaui_entry_wrapper_emit_signal (mgwrap);
 		}
 		else {
-			check_correct_init (wrapper);
-			(*wrapper->priv->real_class->real_set_value) (wrapper, NULL);
-			gdaui_entry_wrapper_emit_signal (wrapper);
+			check_correct_init (mgwrap);
+			(*mgwrap->priv->real_class->real_set_value) (mgwrap, NULL);
+			gdaui_entry_wrapper_emit_signal (mgwrap);
 		}
 	}
 }
@@ -612,12 +609,12 @@ gdaui_entry_wrapper_set_value_default (GdauiDataEntry *iface, const GValue *valu
 static void
 gdaui_entry_wrapper_set_attributes (GdauiDataEntry *iface, GdaValueAttribute attrs, guint mask)
 {
-	GdauiEntryWrapper *wrapper;
+	GdauiEntryWrapper *mgwrap;
 	gboolean signal_contents_changed = FALSE;
 
 	g_return_if_fail (GDAUI_IS_ENTRY_WRAPPER (iface));
-	wrapper = (GdauiEntryWrapper*) iface;
-	check_correct_init (wrapper);
+	mgwrap = (GdauiEntryWrapper*) iface;
+	check_correct_init (mgwrap);
 
 	/* Setting to NULL */
 	if (mask & GDA_VALUE_ATTR_IS_NULL) {
@@ -625,27 +622,27 @@ gdaui_entry_wrapper_set_attributes (GdauiDataEntry *iface, GdaValueAttribute att
 		    !(attrs & GDA_VALUE_ATTR_CAN_BE_NULL))
 			g_return_if_reached ();
 		if (attrs & GDA_VALUE_ATTR_IS_NULL) {
-			block_signals (wrapper);
+			block_signals (mgwrap);
 			gdaui_entry_wrapper_set_value (iface, NULL);
-			unblock_signals (wrapper);
-			wrapper->priv->null_forced = TRUE;
+			unblock_signals (mgwrap);
+			mgwrap->priv->null_forced = TRUE;
 
 			/* if default is set, see if we can keep it that way */
-			if (wrapper->priv->default_forced) {
-				if (G_VALUE_TYPE (wrapper->priv->value_default) !=
+			if (mgwrap->priv->default_forced) {
+				if (G_VALUE_TYPE (mgwrap->priv->value_default) !=
 				    GDA_TYPE_NULL) {
-					wrapper->priv->default_forced = FALSE;
+					mgwrap->priv->default_forced = FALSE;
 				}
 			}
 		}
 		else
-			wrapper->priv->null_forced = FALSE;
+			mgwrap->priv->null_forced = FALSE;
 		signal_contents_changed = TRUE;
 	}
 
 	/* Can be NULL ? */
 	if (mask & GDA_VALUE_ATTR_CAN_BE_NULL)
-		wrapper->priv->null_possible = (attrs & GDA_VALUE_ATTR_CAN_BE_NULL) ? TRUE : FALSE;
+		mgwrap->priv->null_possible = (attrs & GDA_VALUE_ATTR_CAN_BE_NULL) ? TRUE : FALSE;
 
 	/* Setting to DEFAULT */
 	guint current = gdaui_data_entry_get_attributes (iface);
@@ -653,43 +650,43 @@ gdaui_entry_wrapper_set_attributes (GdauiDataEntry *iface, GdaValueAttribute att
 		if (! (current & GDA_VALUE_ATTR_CAN_BE_DEFAULT))
 			g_warning ("Data entry does not have a default value");
 		if (attrs & GDA_VALUE_ATTR_IS_DEFAULT) {
-			block_signals (wrapper);
-			if (wrapper->priv->value_default) {
-				if (G_VALUE_TYPE (wrapper->priv->value_default) == wrapper->priv->type)
-					gdaui_entry_wrapper_set_value (iface, wrapper->priv->value_default);
+			block_signals (mgwrap);
+			if (mgwrap->priv->value_default) {
+				if (G_VALUE_TYPE (mgwrap->priv->value_default) == mgwrap->priv->type)
+					gdaui_entry_wrapper_set_value (iface, mgwrap->priv->value_default);
 				else
-					(*wrapper->priv->real_class->real_set_value) (wrapper, NULL);
+					(*mgwrap->priv->real_class->real_set_value) (mgwrap, NULL);
 			}
 			else
 				gdaui_entry_wrapper_set_value (iface, NULL);
-			unblock_signals (wrapper);
+			unblock_signals (mgwrap);
 
 			/* if NULL is set, see if we can keep it that way */
-			if (wrapper->priv->null_forced) {
-				if (G_VALUE_TYPE (wrapper->priv->value_default) !=
+			if (mgwrap->priv->null_forced) {
+				if (G_VALUE_TYPE (mgwrap->priv->value_default) !=
 				    GDA_TYPE_NULL)
-					wrapper->priv->null_forced = FALSE;
+					mgwrap->priv->null_forced = FALSE;
 			}
 
-			wrapper->priv->default_forced = TRUE;
+			mgwrap->priv->default_forced = TRUE;
 		}
 		else
-			wrapper->priv->default_forced = FALSE;
+			mgwrap->priv->default_forced = FALSE;
 
 		signal_contents_changed = TRUE;
 	}
 
 	/* Can be DEFAULT ? */
 	if (mask & GDA_VALUE_ATTR_CAN_BE_DEFAULT)
-		wrapper->priv->default_possible = (attrs & GDA_VALUE_ATTR_CAN_BE_DEFAULT) ? TRUE : FALSE;
+		mgwrap->priv->default_possible = (attrs & GDA_VALUE_ATTR_CAN_BE_DEFAULT) ? TRUE : FALSE;
 
 	/* Modified ? */
 	if (mask & GDA_VALUE_ATTR_IS_UNCHANGED) {
 		if (attrs & GDA_VALUE_ATTR_IS_UNCHANGED) {
-			wrapper->priv->default_forced = FALSE;
-			block_signals (wrapper);
-			gdaui_entry_wrapper_set_value (iface, wrapper->priv->value_ref);
-			unblock_signals (wrapper);
+			mgwrap->priv->default_forced = FALSE;
+			block_signals (mgwrap);
+			gdaui_entry_wrapper_set_value (iface, mgwrap->priv->value_ref);
+			unblock_signals (mgwrap);
 			signal_contents_changed = TRUE;
 		}
 	}
@@ -697,12 +694,12 @@ gdaui_entry_wrapper_set_attributes (GdauiDataEntry *iface, GdaValueAttribute att
 	/* Actions buttons ? */
 	if (mask & GDA_VALUE_ATTR_ACTIONS_SHOWN) {
 		GValue *gval;
-		wrapper->priv->show_actions = (attrs & GDA_VALUE_ATTR_ACTIONS_SHOWN) ? TRUE : FALSE;
+		mgwrap->priv->show_actions = (attrs & GDA_VALUE_ATTR_ACTIONS_SHOWN) ? TRUE : FALSE;
 
 		gval = g_new0 (GValue, 1);
 		g_value_init (gval, G_TYPE_BOOLEAN);
-		g_value_set_boolean (gval, wrapper->priv->show_actions);
-		g_object_set_property (G_OBJECT (wrapper), "actions", gval);
+		g_value_set_boolean (gval, mgwrap->priv->show_actions);
+		g_object_set_property (G_OBJECT (mgwrap), "actions", gval);
 		g_free (gval);
 	}
 
@@ -716,27 +713,27 @@ gdaui_entry_wrapper_set_attributes (GdauiDataEntry *iface, GdaValueAttribute att
 	current = gdaui_data_entry_get_attributes (iface);
 
 	if (signal_contents_changed) {
-		wrapper->priv->contents_has_changed = FALSE;
-		gdaui_entry_wrapper_emit_signal (wrapper);
+		mgwrap->priv->contents_has_changed = FALSE;
+		gdaui_entry_wrapper_emit_signal (mgwrap);
 	}
-	g_signal_emit_by_name (G_OBJECT (wrapper), "status-changed");
+	g_signal_emit_by_name (G_OBJECT (mgwrap), "status-changed");
 }
 
 static GdaValueAttribute
 gdaui_entry_wrapper_get_attributes (GdauiDataEntry *iface)
 {
 	GdaValueAttribute retval = 0;
-	GdauiEntryWrapper *wrapper;
+	GdauiEntryWrapper *mgwrap;
 	GValue *value = NULL;
 	gboolean has_current_value;
 	gboolean value_is_null = FALSE;
 
 	g_return_val_if_fail (GDAUI_IS_ENTRY_WRAPPER (iface), 0);
-	wrapper = (GdauiEntryWrapper*) iface;
+	mgwrap = (GdauiEntryWrapper*) iface;
 
-	check_correct_init (wrapper);
-	if (!wrapper->priv->real_class->value_is_equal_to ||
-	    !wrapper->priv->real_class->value_is_null) {
+	check_correct_init (mgwrap);
+	if (!mgwrap->priv->real_class->value_is_equal_to ||
+	    !mgwrap->priv->real_class->value_is_null) {
 		value = gdaui_entry_wrapper_get_value (iface);
 		has_current_value = TRUE;
 	}
@@ -746,8 +743,8 @@ gdaui_entry_wrapper_get_attributes (GdauiDataEntry *iface)
 	/* NULL? */
 	if (has_current_value) {
 		if ((value && (G_VALUE_TYPE (value) == GDA_TYPE_NULL)) || !value) {
-			if (wrapper->priv->default_forced) {
-				if (wrapper->priv->null_forced)
+			if (mgwrap->priv->default_forced) {
+				if (mgwrap->priv->null_forced)
 					value_is_null = TRUE;
 			}
 			else
@@ -755,58 +752,58 @@ gdaui_entry_wrapper_get_attributes (GdauiDataEntry *iface)
 		}
 	}
 	else {
-		if ((wrapper->priv->real_class->value_is_null) (wrapper))
+		if ((mgwrap->priv->real_class->value_is_null) (mgwrap))
 			value_is_null = TRUE;
 	}
 	if (value_is_null)
 		retval = retval | GDA_VALUE_ATTR_IS_NULL;
 
 	/* can be NULL? */
-	if (wrapper->priv->null_possible)
+	if (mgwrap->priv->null_possible)
 		retval = retval | GDA_VALUE_ATTR_CAN_BE_NULL;
 
 	/* is default */
-	if (wrapper->priv->default_forced)
+	if (mgwrap->priv->default_forced)
 		retval = retval | GDA_VALUE_ATTR_IS_DEFAULT;
 
 	/* can be default? */
-	if (wrapper->priv->default_possible)
+	if (mgwrap->priv->default_possible)
 		retval = retval | GDA_VALUE_ATTR_CAN_BE_DEFAULT;
 
 	/* is unchanged */
 	if (has_current_value) {
-		if (wrapper->priv->value_ref &&
-		    (G_VALUE_TYPE (value) == G_VALUE_TYPE (wrapper->priv->value_ref))) {
+		if (mgwrap->priv->value_ref &&
+		    (G_VALUE_TYPE (value) == G_VALUE_TYPE (mgwrap->priv->value_ref))) {
 			if (gda_value_is_null (value))
 				retval = retval | GDA_VALUE_ATTR_IS_UNCHANGED;
 			else {
-				if (! gda_value_differ (value, wrapper->priv->value_ref))
+				if (! gda_value_differ (value, mgwrap->priv->value_ref))
 					retval = retval | GDA_VALUE_ATTR_IS_UNCHANGED;
 			}
 		}
 	}
-	else if ((wrapper->priv->real_class->value_is_equal_to) (wrapper, wrapper->priv->value_ref))
+	else if ((mgwrap->priv->real_class->value_is_equal_to) (mgwrap, mgwrap->priv->value_ref))
 		retval = retval | GDA_VALUE_ATTR_IS_UNCHANGED;
 
 	/* actions shown */
-	if (wrapper->priv->show_actions)
+	if (mgwrap->priv->show_actions)
 		retval = retval | GDA_VALUE_ATTR_ACTIONS_SHOWN;
 
 	/* data valid? */
-	if (! (wrapper->priv->default_forced && wrapper->priv->default_possible)) {
-		if (/*(value_is_null && !wrapper->priv->null_forced) ||*/
-		    (value_is_null && !wrapper->priv->null_possible))
+	if (! (mgwrap->priv->default_forced && mgwrap->priv->default_possible)) {
+		if (/*(value_is_null && !mgwrap->priv->null_forced) ||*/
+		    (value_is_null && !mgwrap->priv->null_possible))
 			retval = retval | GDA_VALUE_ATTR_DATA_NON_VALID;
 	}
 
 	/* has original value? */
-	if (wrapper->priv->value_ref)
+	if (mgwrap->priv->value_ref)
 		retval = retval | GDA_VALUE_ATTR_HAS_VALUE_ORIG;
 
 	if (has_current_value)
 		gda_value_free (value);
 
-	if (!wrapper->priv->editable)
+	if (!mgwrap->priv->editable)
 		retval = retval | GDA_VALUE_ATTR_NO_MODIF;
 
 	return retval;
@@ -830,27 +827,27 @@ gdaui_entry_wrapper_get_handler (GdauiDataEntry *iface)
 static gboolean
 gdaui_entry_wrapper_can_expand (GdauiDataEntry *iface, gboolean horiz)
 {
-	GdauiEntryWrapper *wrapper;
+	GdauiEntryWrapper *mgwrap;
 
 	g_return_val_if_fail (GDAUI_IS_ENTRY_WRAPPER (iface), FALSE);
-	wrapper = (GdauiEntryWrapper*) iface;
-	check_correct_init (wrapper);
+	mgwrap = (GdauiEntryWrapper*) iface;
+	check_correct_init (mgwrap);
 
-	return (wrapper->priv->real_class->can_expand) (wrapper, horiz);
+	return (mgwrap->priv->real_class->can_expand) (mgwrap, horiz);
 }
 
 static void
 gdaui_entry_wrapper_set_editable (GdauiDataEntry *iface, gboolean editable)
 {
-	GdauiEntryWrapper *wrapper;
+	GdauiEntryWrapper *mgwrap;
 
 	g_return_if_fail (GDAUI_IS_ENTRY_WRAPPER (iface));
-	wrapper = (GdauiEntryWrapper*) iface;
-	check_correct_init (wrapper);
+	mgwrap = (GdauiEntryWrapper*) iface;
+	check_correct_init (mgwrap);
 
-	wrapper->priv->editable = editable;
-	if (wrapper->priv->real_class->set_editable)
-		(wrapper->priv->real_class->set_editable) (wrapper, editable);
+	mgwrap->priv->editable = editable;
+	if (mgwrap->priv->real_class->set_editable)
+		(mgwrap->priv->real_class->set_editable) (mgwrap, editable);
 	else
 		gtk_widget_set_sensitive (GTK_WIDGET (iface), editable);
 }
@@ -858,36 +855,29 @@ gdaui_entry_wrapper_set_editable (GdauiDataEntry *iface, gboolean editable)
 static gboolean
 gdaui_entry_wrapper_get_editable (GdauiDataEntry *iface)
 {
-	GdauiEntryWrapper *wrapper;
+	GdauiEntryWrapper *mgwrap;
 
 	g_return_val_if_fail (GDAUI_IS_ENTRY_WRAPPER (iface), FALSE);
-	wrapper = (GdauiEntryWrapper*) iface;
+	mgwrap = (GdauiEntryWrapper*) iface;
 
-	return wrapper->priv->editable;
+	return mgwrap->priv->editable;
 }
 
 static void
 gdaui_entry_wrapper_grab_focus (GdauiDataEntry *iface)
 {
-	GdauiEntryWrapper *wrapper;
+	GdauiEntryWrapper *mgwrap;
 
 	g_return_if_fail (GDAUI_IS_ENTRY_WRAPPER (iface));
-	wrapper = (GdauiEntryWrapper*) iface;
-	check_correct_init (wrapper);
+	mgwrap = (GdauiEntryWrapper*) iface;
+	check_correct_init (mgwrap);
 
-	if (wrapper->priv->real_class->grab_focus)
-		(wrapper->priv->real_class->grab_focus) (wrapper);
-	else if (wrapper->priv->entry) {
+	if (mgwrap->priv->real_class->grab_focus)
+		(mgwrap->priv->real_class->grab_focus) (mgwrap);
+	else if (mgwrap->priv->entry) {
 		gboolean canfocus;
-		g_object_get ((GObject*) wrapper->priv->entry, "can-focus", &canfocus, NULL);
+		g_object_get ((GObject*) mgwrap->priv->entry, "can-focus", &canfocus, NULL);
 		if (canfocus)
-			gtk_widget_grab_focus (wrapper->priv->entry);
+			gtk_widget_grab_focus (mgwrap->priv->entry);
 	}
 }
-
-static void
-gdaui_entry_wrapper_set_unknown_color (GdauiDataEntry *de, gdouble red, gdouble green,
-				       gdouble blue, gdouble alpha)
-{
-	gdaui_entry_shell_set_ucolor (GDAUI_ENTRY_SHELL (de), red, green, blue, alpha);
-}
