@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2010 - 2011 Vivien Malerba <malerba@gnome-db.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -18,7 +18,6 @@
  */
 #include <gtk/gtk.h>
 
-#if GTK_CHECK_VERSION(2,20,0)
 #define WIDGET_EMBEDDER_TYPE              (widget_embedder_get_type ())
 #define WIDGET_EMBEDDER(obj)              (G_TYPE_CHECK_INSTANCE_CAST ((obj), WIDGET_EMBEDDER_TYPE, WidgetEmbedder))
 #define WIDGET_EMBEDDER_CLASS(klass)      (G_TYPE_CHECK_CLASS_CAST ((klass), WIDGET_EMBEDDER_TYPE, WidgetEmbedderClass))
@@ -36,12 +35,6 @@ struct _WidgetEmbedder
 	GtkWidget *child;
 	GdkWindow *offscreen_window;
 	gboolean   valid;
-
-	/* unknown colors */
-	gdouble red;
-	gdouble green;
-	gdouble blue;
-	gdouble alpha;
 };
 
 struct _WidgetEmbedderClass
@@ -49,10 +42,7 @@ struct _WidgetEmbedderClass
 	GtkContainerClass parent_class;
 };
 
-GType      widget_embedder_get_type   (void) G_GNUC_CONST;
-GtkWidget* widget_embedder_new        (void);
-void       widget_embedder_set_valid  (WidgetEmbedder *bin, gboolean valid);
-void       widget_embedder_set_ucolor (WidgetEmbedder *bin, gdouble red, gdouble green,
-				       gdouble blue, gdouble alpha);
+GType      widget_embedder_get_type  (void) G_GNUC_CONST;
+GtkWidget* widget_embedder_new       (void);
+void       widget_embedder_set_valid (WidgetEmbedder *bin, gboolean valid);
 
-#endif
