@@ -1,7 +1,6 @@
 /*
- * Copyright (C) 2009 - 2012 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2009 - 2011 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2010 David King <davidk@openismus.com>
- * Copyright (C) 2011 Murray Cumming <murrayc@murrayc.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -26,7 +25,6 @@
 #include <gdk/gdkkeysyms.h>
 #include "internal/popup-container.h"
 #include "gdaui-data-selector.h"
-#include <libgda/gda-debug-macros.h>
 
 static void gdaui_cloud_class_init (GdauiCloudClass * class);
 static void gdaui_cloud_init (GdauiCloud *wid);
@@ -731,12 +729,8 @@ static gboolean
 visibility_notify_event (GtkWidget *text_view, G_GNUC_UNUSED GdkEventVisibility *event, GdauiCloud *cloud)
 {
 	gint wx, wy, bx, by;
-	GdkDeviceManager *manager;
-        GdkDevice *pointer;
 
-        manager = gdk_display_get_device_manager (gtk_widget_get_display (text_view));
-        pointer = gdk_device_manager_get_client_pointer (manager);
-	gdk_window_get_device_position (gtk_widget_get_window (text_view), pointer, &wx, &wy, NULL);
+	gdk_window_get_pointer (gtk_widget_get_window (text_view), &wx, &wy, NULL);
 	
 	gtk_text_view_window_to_buffer_coords (GTK_TEXT_VIEW (text_view), 
 					       GTK_TEXT_WINDOW_WIDGET,
@@ -760,6 +754,8 @@ motion_notify_event (GtkWidget *text_view, GdkEventMotion *event, GdauiCloud *cl
 					       event->x, event->y, &x, &y);
 	
 	set_cursor_if_appropriate (GTK_TEXT_VIEW (text_view), x, y, cloud);
+	
+	gdk_window_get_pointer (gtk_widget_get_window (text_view), NULL, NULL, NULL);
 	return FALSE;
 }
 
@@ -880,7 +876,6 @@ key_press_event (GtkWidget *text_view, GdkEventKey *event, GdauiCloud *cloud)
 					mvt_type = GTK_MOVEMENT_VISUAL_POSITIONS;
 					mvt_amount = -1;
 					break;
-				default:
 				case GDK_KEY_Right:
 					done = ! gtk_text_iter_forward_char (&iter);
 					mvt_type = GTK_MOVEMENT_VISUAL_POSITIONS;
@@ -1086,7 +1081,7 @@ gdaui_cloud_create_filter_widget (GdauiCloud *cloud)
 /**
  * gdaui_cloud_set_weight_func:
  * @cloud: a #GdauiCloud widget
- * @func: (allow-none) (scope notified): a #GdauiCloudWeightFunc function which computes weights, or %NULL to unset
+ * @func: (allow-none): a #GdauiCloudWeightFunc function which computes weights, or %NULL to unset
  * @data: (allow-none): a pointer to pass as last argument of @func each time it is called, or %NULL
  *
  * Specifies a function called by @cloud to compute each row's respective weight.
