@@ -1,7 +1,6 @@
 /*
  * Copyright (C) 2009 - 2011 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2010 David King <davidk@openismus.com>
- * Copyright (C) 2012 Snicksie <none@none.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -375,7 +374,7 @@ create_data_error_dialog (GdauiDataProxy *form, gboolean with_question, gboolean
 		if (with_question)
 			msg2 =_("You may now choose to correct it, or to discard "
 				"the modifications.\n\n"
-				"What do you want to do?");
+				"What do you wan to do?");
 		else
 			msg2 = _("please correct it and try again, or discard "
 				 "the modifications.");
