@@ -57,12 +57,8 @@
 #include <io.h>
 #endif
 
-#ifdef HAVE_LIBSECRET
-  #include <libsecret/secret.h>
-#else
-  #ifdef HAVE_GNOME_KEYRING
-  #include <gnome-keyring.h>
-  #endif
+#ifdef HAVE_GNOME_KEYRING
+#include <gnome-keyring.h>
 #endif
 
 typedef struct {
@@ -97,12 +93,8 @@ static void gda_config_get_property (GObject *object,
 				     GValue *value,
 				     GParamSpec *pspec);
 static GdaConfig *unique_instance = NULL;
-#ifdef HAVE_LIBSECRET
+#ifdef HAVE_GNOME_KEYRING
 static gboolean sync_keyring = FALSE;
-#else
-  #ifdef HAVE_GNOME_KEYRING
-static gboolean sync_keyring = FALSE;
-  #endif
 #endif
 
 static gint data_source_info_compare (GdaDsnInfo *infoa, GdaDsnInfo *infob);
@@ -148,15 +140,9 @@ static void lock_notify_changes (void);
 static void unlock_notify_changes (void);
 #endif
 
-#if GLIB_CHECK_VERSION(2,31,7)
-static GRecMutex gda_rmutex;
-#define GDA_CONFIG_LOCK() g_rec_mutex_lock(&gda_rmutex)
-#define GDA_CONFIG_UNLOCK() g_rec_mutex_unlock(&gda_rmutex)
-#else
 static GStaticRecMutex gda_mutex = G_STATIC_REC_MUTEX_INIT;
 #define GDA_CONFIG_LOCK() g_static_rec_mutex_lock(&gda_mutex)
 #define GDA_CONFIG_UNLOCK() g_static_rec_mutex_unlock(&gda_mutex)
-#endif
 
 /* GdaServerProvider for SQLite as a shortcut, available
  * even if the SQLite provider is not installed
@@ -256,7 +242,7 @@ gda_config_class_init (GdaConfigClass *klass)
 	 * File to use for system-wide DSN list. When changed, the whole list of DSN will be reloaded.
 	 */
 	/* To translators: DSN stands for Data Source Name, it's a named connection string defined in $PREFIX/etc/libgda-5.0/config */
-	g_object_class_install_property (object_class, PROP_SYSTEM_FILE,
+	g_object_class_install_property (object_class, PROP_USER_FILE,
                                          g_param_spec_string ("system-filename", NULL,
 							      "File to use for system-wide DSN list", 
 							      NULL,
@@ -281,37 +267,7 @@ gda_config_init (GdaConfig *conf, G_GNUC_UNUSED GdaConfigClass *klass)
 	conf->priv->emit_signals = TRUE;
 }
 
-#ifdef HAVE_LIBSECRET
-static void
-secret_password_found_cb (GObject *source_object, GAsyncResult *res, gchar *dsnname)
-{
-	gchar *auth;
-	GError *error = NULL;
-	auth = secret_password_lookup_finish (res, &error);
-        if (auth) {
-		GdaDsnInfo *dsn;
-		dsn = gda_config_get_dsn_info (dsnname);
-		if (dsn) {
-			if (dsn->auth_string && auth && !strcmp (dsn->auth_string, auth))
-				return;
-
-			g_free (dsn->auth_string);
-			dsn->auth_string = g_strdup (auth);
-		}
-		/*g_print ("Loaded auth info for '%s'\n", dsnname);*/
-		if (unique_instance->priv->emit_signals)
-			g_signal_emit (unique_instance, gda_config_signals [DSN_CHANGED], 0, dsn);
-		g_free (auth);
-	}
-	else if (error) {
-		gda_log_message (_("Error loading authentication information for '%s' DSN: %s"),
-				 dsnname, error->message ? error->message : _("No detail"));
-		g_clear_error (&error);
-	}
-	g_free (dsnname);
-}
-#else
-  #ifdef HAVE_GNOME_KEYRING
+#ifdef HAVE_GNOME_KEYRING
 static void
 password_found_cb (GnomeKeyringResult res, const gchar *password, const gchar *dsnname)
 {
@@ -330,10 +286,9 @@ password_found_cb (GnomeKeyringResult res, const gchar *password, const gchar *d
 			g_signal_emit (unique_instance, gda_config_signals [DSN_CHANGED], 0, dsn);
 	}
 	else if (res != GNOME_KEYRING_RESULT_NO_MATCH)
-		gda_log_message (_("Error loading authentication information for '%s' DSN: %s"),
+		gda_log_message (_("Error loading authentification information for '%s' DSN: %s"),
 				 dsnname, gnome_keyring_result_to_message (res));
 }
-  #endif
 #endif
 
 static void
@@ -440,34 +395,7 @@ load_config_file (const gchar *file, gboolean is_system)
 			g_free (username);
 			g_free (password);
 
-#ifdef HAVE_LIBSECRET
-			if (! is_system) {
-				if (sync_keyring) {
-					GError *error = NULL;
-					gchar *auth = NULL;
-					auth = secret_password_lookup_sync (SECRET_SCHEMA_COMPAT_NETWORK,
-									    NULL, &error,
-									    "server", info->name, NULL);
-					if (auth) {
-						/*g_print ("Loaded sync. auth info for '%s': %s\n", info->name, auth);*/
-						info->auth_string = g_strdup (auth);
-						g_free (auth);
-					}
-					else if (error) {
-						gda_log_message (_("Error loading authentication information for '%s' DSN: %s"),
-								 info->name, error->message ? error->message : _("No detail"));
-						g_clear_error (&error);
-					}
-				}
-				else {
-					secret_password_lookup (SECRET_SCHEMA_COMPAT_NETWORK,
-								NULL, (GAsyncReadyCallback) secret_password_found_cb,
-								g_strdup (info->name),
-								"server", info->name, NULL);
-				}
-			}
-#else
-  #ifdef HAVE_GNOME_KEYRING
+#ifdef HAVE_GNOME_KEYRING
 			if (! is_system) {
 				if (sync_keyring) {
 					GnomeKeyringResult res;
@@ -479,7 +407,7 @@ load_config_file (const gchar *file, gboolean is_system)
 						info->auth_string = g_strdup (auth);
 					}
 					else if (res != GNOME_KEYRING_RESULT_NO_MATCH)
-						gda_log_message (_("Error loading authentication information for '%s' DSN: %s"),
+						gda_log_message (_("Error loading authentification information for '%s' DSN: %s"),
 								 info->name, gnome_keyring_result_to_message (res));
 					if (auth)
 						gnome_keyring_free_password (auth);
@@ -492,7 +420,6 @@ load_config_file (const gchar *file, gboolean is_system)
 								     "server", tmp, NULL);
 				}
 			}
-  #endif
 #endif
 			/* signals */
 			if (is_new) {
@@ -550,7 +477,7 @@ save_config_file (gboolean is_system)
 		xmlSetProp (entry, BAD_CAST "type", BAD_CAST "string");
 		xmlSetProp (entry, BAD_CAST "value", BAD_CAST (info->cnc_string));
 
-#if !defined (HAVE_GNOME_KEYRING) && !defined (HAVE_LIBSECRET)
+#ifndef HAVE_GNOME_KEYRING
 		if (! is_system) {
 			/* auth */
 			entry = xmlNewChild (section, NULL, BAD_CAST "entry", NULL);
@@ -593,7 +520,7 @@ gda_config_constructor (GType type,
 	GObject *object;
   
 	if (!unique_instance) {
-#if defined(HAVE_LIBSECRET) || defined(HAVE_GNOME_KEYRING)
+#ifdef HAVE_GNOME_KEYRING
 		if (g_getenv ("GDA_CONFIG_SYNCHRONOUS"))
 			sync_keyring = TRUE;
 #endif
@@ -982,28 +909,14 @@ gda_config_get_dsn_info (const gchar *dsn_name)
 	return NULL;
 }
 
-#ifdef HAVE_LIBSECRET
-static void
-secret_password_stored_cb (GObject *source_object, GAsyncResult *res, gchar *dsnname)
-{
-	GError *error = NULL;
-	if (! secret_password_store_finish (res, &error)) {
-		gda_log_error (_("Couldn't save authentication information for DSN '%s': %s"),
-			       dsnname, error && error->message ? error->message : _("No detail"));
-		g_clear_error (&error);
-	}
-	g_free (dsnname);
-}
-#else
-  #ifdef HAVE_GNOME_KEYRING
+#ifdef HAVE_GNOME_KEYRING
 static void
 password_stored_cb (GnomeKeyringResult res, const gchar *dsnname)
 {
         if (res != GNOME_KEYRING_RESULT_OK)
-                gda_log_error (_("Couldn't save authentication information for DSN '%s': %s"), dsnname,
+                gda_log_error (_("Couldn't save authentification information for DSN '%s': %s"), dsnname,
 			       gnome_keyring_result_to_message (res));
 }
-  #endif
 #endif
 
 /**
@@ -1084,43 +997,11 @@ gda_config_define_dsn (const GdaDsnInfo *info, GError **error)
 			g_signal_emit (unique_instance, gda_config_signals[DSN_ADDED], 0, einfo);
 	}
 
-#ifdef HAVE_LIBSECRET
-	if (! info->is_system && info->auth_string) {
+#ifdef HAVE_GNOME_KEYRING
+	if (! info->is_system) {
 		/* save to keyring */
 		gchar *tmp;
-		tmp = g_strdup_printf (_("Authentication for the '%s' DSN"), info->name);
-		if (sync_keyring) {
-			gboolean res;
-			GError *error = NULL;
-			res = secret_password_store_sync (SECRET_SCHEMA_COMPAT_NETWORK,
-							  SECRET_COLLECTION_DEFAULT,
-							  tmp, info->auth_string,
-							  NULL, &error,
-							  "server", info->name, NULL);
-			if (!res) {
-				gda_log_error (_("Couldn't save authentication information for DSN '%s': %s"),
-					       info->name,
-					       error && error->message ? error->message : _("No detail"));
-				g_clear_error (&error);
-			}
-		}
-		else {
-			secret_password_store (SECRET_SCHEMA_COMPAT_NETWORK,
-					       SECRET_COLLECTION_DEFAULT,
-					       tmp, info->auth_string,
-					       NULL,
-					       (GAsyncReadyCallback) secret_password_stored_cb,
-					       g_strdup (info->name),
-					       "server", info->name, NULL);
-		}
-		g_free (tmp);
-	}
-#else
-  #ifdef HAVE_GNOME_KEYRING
-	if (! info->is_system && info->auth_string) {
-		/* save to keyring */
-		gchar *tmp;
-		tmp = g_strdup_printf (_("Authentication for the '%s' DSN"), info->name);
+		tmp = g_strdup_printf (_("Authentification for the '%s' DSN"), info->name);
 		if (sync_keyring) {
 			GnomeKeyringResult res;
 			res = gnome_keyring_store_password_sync (GNOME_KEYRING_NETWORK_PASSWORD, GNOME_KEYRING_DEFAULT,
@@ -1139,7 +1020,6 @@ gda_config_define_dsn (const GdaDsnInfo *info, GError **error)
 		}
 		g_free (tmp);
 	}
-  #endif
 #endif
 	
 	if (save_system)
@@ -1151,20 +1031,7 @@ gda_config_define_dsn (const GdaDsnInfo *info, GError **error)
 	return TRUE;
 }
 
-#ifdef HAVE_LIBSECRET
-static void
-secret_password_deleted_cb (GObject *source_object, GAsyncResult *res, gchar *dsnname)
-{
-	GError *error = NULL;
-	if (! secret_password_clear_finish (res, &error)) {
-                gda_log_error (_("Couldn't delete authentication information for DSN '%s': %s"), dsnname,
-			       error && error->message ? error->message : _("No detail"));
-		g_clear_error (&error);
-	}
-	g_free (dsnname);
-}
-#else
-  #ifdef HAVE_GNOME_KEYRING
+#ifdef HAVE_GNOME_KEYRING
 static void
 password_deleted_cb (GnomeKeyringResult res, const gchar *dsnname)
 {
@@ -1172,7 +1039,6 @@ password_deleted_cb (GnomeKeyringResult res, const gchar *dsnname)
                 gda_log_error (_("Couldn't delete authentication information for DSN '%s': %s"), dsnname,
 			       gnome_keyring_result_to_message (res));
 }
-  #endif
 #endif
 
 /**
@@ -1225,29 +1091,7 @@ gda_config_remove_dsn (const gchar *dsn_name, GError **error)
 		g_signal_emit (unique_instance, gda_config_signals[DSN_REMOVED], 0, info);
 	data_source_info_free (info);
 
-#ifdef HAVE_LIBSECRET
-	if (! info->is_system) {
-		/* remove from keyring */
-		if (sync_keyring) {
-			GError *error = NULL;
-			if (! secret_password_clear_sync (SECRET_SCHEMA_COMPAT_NETWORK,
-							  NULL, &error,
-							  "server", info->name, NULL)) {
-				gda_log_error (_("Couldn't delete authentication information for DSN '%s': %s"),
-					       info->name,
-					       error && error->message ? error->message : _("No detail"));
-				g_clear_error (&error);
-			}
-		}
-		else {
-			secret_password_clear (SECRET_SCHEMA_COMPAT_NETWORK,
-					       NULL, (GAsyncReadyCallback) secret_password_deleted_cb,
-					       g_strdup (info->name),
-					       "server", info->name, NULL);
-		}
-	}
-#else
-  #ifdef HAVE_GNOME_KEYRING
+#ifdef HAVE_GNOME_KEYRING
 	if (! info->is_system) {
 		/* remove from keyring */
 		if (sync_keyring) {
@@ -1260,12 +1104,10 @@ gda_config_remove_dsn (const gchar *dsn_name, GError **error)
 			gchar *tmp;
 			tmp = g_strdup (dsn_name);
 			gnome_keyring_delete_password (GNOME_KEYRING_NETWORK_PASSWORD,
-						       (GnomeKeyringOperationDoneCallback) password_deleted_cb,
-						       tmp, g_free,
-						       "server", info->name, NULL);
+						       (GnomeKeyringOperationDoneCallback) password_deleted_cb, tmp, g_free,
+						       "server", tmp, NULL);
 		}
 	}
-  #endif
 #endif
 
 	if (save_system)
@@ -1634,13 +1476,7 @@ gda_config_list_providers (void)
 	GDA_CONFIG_UNLOCK ();
 	return model;
 }
-
-static gint
-internal_provider_sort_func (InternalProvider *a, InternalProvider *b)
-{
-	return strcmp (a->pinfo.id, b->pinfo.id);
-}
-
+ 
 static void load_providers_from_dir (const gchar *dirname, gboolean recurs);
 static void
 load_all_providers (void)
@@ -1668,10 +1504,6 @@ load_all_providers (void)
 		_gda_config_sqlite_provider = (GdaServerProvider*) 
 			g_object_new (GDA_TYPE_SQLITE_PROVIDER, NULL);
 	}
-
-	/* sort providers by name */
-	unique_instance->priv->prov_list = g_slist_sort (unique_instance->priv->prov_list,
-							 (GCompareFunc) internal_provider_sort_func);
 }
 
 static InternalProvider *
@@ -2013,7 +1845,7 @@ reload_dsn_configuration (void)
 			if (str_equal (oinfo->provider, ninfo->provider) && 
 			    str_equal (oinfo->description, ninfo->description) && 
 			    str_equal (oinfo->cnc_string, ninfo->cnc_string) && 
-#if !defined (HAVE_GNOME_KEYRING) && !defined (HAVE_LIBSECRET)
+#ifndef HAVE_GNOME_KEYRING
 			    str_equal (oinfo->auth_string, ninfo->auth_string) && 
 #endif
 			    (oinfo->is_system == ninfo->is_system)) {
