@@ -79,6 +79,8 @@ struct _GdaHolderClass
  *
  * The type of a #GdaHolder has to be set and cannot be modified, except if it's initialized
  * with a GDA_TYPE_NULL GType (representing NULL values) where it can be changed once to a real GType.
+ *
+ * Each GdaHolder object is thread safe.
  */
 
 GType               gda_holder_get_type                (void) G_GNUC_CONST;
@@ -138,7 +140,9 @@ gboolean            gda_holder_set_value_to_default    (GdaHolder *holder);
 gboolean            gda_holder_value_is_default        (GdaHolder *holder);
 
 void                gda_holder_force_invalid           (GdaHolder *holder);
+void                gda_holder_force_invalid_e         (GdaHolder *holder, GError *error);
 gboolean            gda_holder_is_valid                (GdaHolder *holder);
+gboolean            gda_holder_is_valid_e              (GdaHolder *holder, GError **error);
 
 
 void                gda_holder_set_not_null            (GdaHolder *holder, gboolean not_null);
