@@ -1,11 +1,11 @@
 /*
  * Copyright (C) 2009 Bas Driessen <bas.driessen@xobas.com>
  * Copyright (C) 2009 Johannes Schmid <jhs@gnome.org>
- * Copyright (C) 2009 - 2011 Murray Cumming <murrayc@murrayc.com>
- * Copyright (C) 2009 - 2012 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2009 - 2010 Murray Cumming <murrayc@murrayc.com>
+ * Copyright (C) 2009 - 2011 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2010 David King <davidk@openismus.com>
  * Copyright (C) 2010 Jonh Wendell <jwendell@gnome.org>
- * Copyright (C) 2011 Daniel Espinosa <despinosa@src.gnome.org>
+ * Copyright (C) 2011 Daniel Espinosa <esodan@gmail.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -48,6 +48,8 @@ static void gda_sql_builder_get_property (GObject *object,
 					 GValue *value,
 					 GParamSpec *pspec);
 
+static GStaticRecMutex init_mutex = G_STATIC_REC_MUTEX_INIT;
+
 
 typedef struct {
 	GdaSqlAnyPart *part;
@@ -82,7 +84,6 @@ gda_sql_builder_get_type (void) {
 	static GType type = 0;
 
 	if (G_UNLIKELY (type == 0)) {
-		static GStaticMutex registering = G_STATIC_MUTEX_INIT;
 		static const GTypeInfo info = {
 			sizeof (GdaSqlBuilderClass),
 			(GBaseInitFunc) NULL,
@@ -96,10 +97,10 @@ gda_sql_builder_get_type (void) {
 			0
 		};
 
-		g_static_mutex_lock (&registering);
+		g_static_rec_mutex_lock (&init_mutex);
 		if (type == 0)
 			type = g_type_register_static (G_TYPE_OBJECT, "GdaSqlBuilder", &info, 0);
-		g_static_mutex_unlock (&registering);
+		g_static_rec_mutex_unlock (&init_mutex);
 	}
 	return type;
 }
@@ -341,7 +342,7 @@ gda_sql_builder_get_statement (GdaSqlBuilder *builder, GError **error)
 	g_return_val_if_fail (GDA_IS_SQL_BUILDER (builder), NULL);
 	if (!builder->priv->main_stmt) {
 		g_set_error (error, GDA_SQL_BUILDER_ERROR, GDA_SQL_BUILDER_MISUSE_ERROR,
-			     "%s", _("SqlBuilder is empty"));
+			     _("SqlBuilder is empty"));
 		return NULL;
 	}
 	if (! gda_sql_statement_check_structure (builder->priv->main_stmt, error))
@@ -551,11 +552,7 @@ create_typed_value (GType type, va_list *ap)
 	else if (type == GDA_TYPE_USHORT)
 		gda_value_set_ushort ((v = gda_value_new (GDA_TYPE_USHORT)), va_arg (*ap, guint));
 	else if (type == G_TYPE_CHAR)
-#if GLIB_CHECK_VERSION(2,31,7)
-		g_value_set_schar ((v = gda_value_new (G_TYPE_CHAR)), va_arg (*ap, gint));
-#else
 		g_value_set_char ((v = gda_value_new (G_TYPE_CHAR)), va_arg (*ap, gint));
-#endif
 	else if (type == G_TYPE_UCHAR)
 		g_value_set_uchar ((v = gda_value_new (G_TYPE_UCHAR)), va_arg (*ap, guint));
 	else if (type == G_TYPE_FLOAT)
@@ -823,6 +820,7 @@ gda_sql_builder_add_expr_value (GdaSqlBuilder *builder, G_GNUC_UNUSED GdaDataHan
 	g_return_val_if_fail (GDA_IS_SQL_BUILDER (builder), 0);
 	g_return_val_if_fail (builder->priv->main_stmt, 0);
 
+	gchar *str;
 	GdaSqlExpr *expr;
 	expr = gda_sql_expr_new (NULL);
 	if (value && (G_VALUE_TYPE (value) != GDA_TYPE_NULL)) {
@@ -1662,7 +1660,6 @@ gda_sql_builder_add_function (GdaSqlBuilder *builder, const gchar *func_name, ..
 		if (!part) {
 			expr->func->args_list = list;
 			gda_sql_expr_free (expr);
-			va_end (ap);
 			return 0;
 		}
 		list = g_slist_prepend (list, use_part (part, GDA_SQL_ANY_PART (expr->func)));
@@ -1908,7 +1905,6 @@ gda_sql_builder_add_case (GdaSqlBuilder *builder,
 	return add_part (builder, (GdaSqlAnyPart *) expr);
 
  cleanups:
-	va_end (ap);
 	gda_sql_expr_free (expr);
 	return 0;
 }
