@@ -1,7 +1,7 @@
 /*
  * Copyright (C) 2008 Bas Driessen <bas.driessen@xobas.com>
- * Copyright (C) 2008 - 2011 Murray Cumming <murrayc@murrayc.com>
- * Copyright (C) 2008 - 2012 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2008 Murray Cumming <murrayc@murrayc.com>
+ * Copyright (C) 2008 - 2011 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2010 David King <davidk@openismus.com>
  * Copyright (C) 2010 Jonh Wendell <jwendell@gnome.org>
  *
@@ -131,7 +131,7 @@ gda_statement_class_init (GdaStatementClass * klass)
 	parent_class = g_type_class_peek_parent (klass);
 
 	/**
-	 * GdaStatement::reset:
+	 * GdaStatement::reset
 	 * @stmt: the #GdaStatement object
 	 *
 	 * Gets emitted whenever the @stmt has changed
@@ -145,7 +145,7 @@ gda_statement_class_init (GdaStatementClass * klass)
 			      g_cclosure_marshal_VOID__VOID, G_TYPE_NONE,
 			      0);
 	/**
-	 * GdaStatement::checked:
+	 * GdaStatement::checked
 	 * @stmt: the #GdaStatement object
 	 *
 	 * Gets emitted whenever the structure and contents
@@ -198,7 +198,7 @@ gda_statement_new (void)
 	return GDA_STATEMENT (obj);
 }
 
-GdaSqlStatement *
+const GdaSqlStatement *
 _gda_statement_get_internal_struct (GdaStatement *stmt)
 {
 	return stmt->priv->internal_struct;
@@ -653,7 +653,6 @@ static gchar *default_render_select_target (GdaSqlSelectTarget *target, GdaSqlRe
 static gchar *default_render_select_join (GdaSqlSelectJoin *join, GdaSqlRenderingContext *context, GError **error);
 static gchar *default_render_select_from (GdaSqlSelectFrom *from, GdaSqlRenderingContext *context, GError **error);
 static gchar *default_render_select_order (GdaSqlSelectOrder *order, GdaSqlRenderingContext *context, GError **error);
-static gchar *default_render_distinct (GdaSqlStatementSelect *select, GdaSqlRenderingContext *context, GError **error);
 
 /**
  * gda_statement_to_sql_real:
@@ -715,8 +714,6 @@ gda_statement_to_sql_real (GdaStatement *stmt, GdaSqlRenderingContext *context,
 		context->render_select_from = (GdaSqlRenderingFunc) default_render_select_from;
 	if (!context->render_select_order)
 		context->render_select_order = (GdaSqlRenderingFunc) default_render_select_order;
-	if (!context->render_distinct)
-		context->render_distinct = (GdaSqlRenderingFunc) default_render_distinct;
 
 	cinfo = gda_sql_statement_get_contents_infos (stmt->priv->internal_struct->stmt_type);
 	if (cinfo->check_structure_func && !cinfo->check_structure_func (GDA_SQL_ANY_PART (stmt->priv->internal_struct->contents), 
@@ -1147,36 +1144,6 @@ default_render_compound (GdaSqlStatementCompound *stmt, GdaSqlRenderingContext *
 	return NULL;	
 }
 
-static gchar *
-default_render_distinct (GdaSqlStatementSelect *stmt, GdaSqlRenderingContext *context, GError **error)
-{
-	gboolean pretty = context->flags & GDA_STATEMENT_SQL_PRETTY;
-	g_return_val_if_fail (stmt, NULL);
-	g_return_val_if_fail (GDA_SQL_ANY_PART (stmt)->type == GDA_SQL_ANY_STMT_SELECT, NULL);
-
-	if (stmt->distinct) {
-		GString *string;
-		string = g_string_new ("DISTINCT");
-		if (stmt->distinct_expr) {
-			gchar *str;
-			str = context->render_expr (stmt->distinct_expr, context, NULL, NULL, error);
-			if (!str) {
-				g_string_free (string, TRUE);
-				return NULL;
-			}
-			g_string_append (string, " ON (");
-			g_string_append (string, str);
-			g_string_append (string, ") ");
-			g_free (str);
-		}
-		if (pretty)
-			g_string_append_c (string, '\n');
-		return g_string_free (string, FALSE);
-	}
-	else
-		return NULL;
-}
-
 static gchar *
 default_render_select (GdaSqlStatementSelect *stmt, GdaSqlRenderingContext *context, GError **error)
 {
@@ -1191,11 +1158,17 @@ default_render_select (GdaSqlStatementSelect *stmt, GdaSqlRenderingContext *cont
 	string = g_string_new ("SELECT ");
 	/* distinct */
 	if (stmt->distinct) {
-		str = context->render_distinct (GDA_SQL_ANY_PART (stmt), context, error);
-		if (!str) goto err;
-		g_string_append (string, str);
-		g_string_append_c (string, ' ');
-		g_free (str);
+		g_string_append (string, "DISTINCT ");
+		if (stmt->distinct_expr) {
+			str = context->render_expr (stmt->distinct_expr, context, NULL, NULL, error);
+			if (!str) goto err;
+			g_string_append (string, "ON ");
+			g_string_append (string, str);
+			g_string_append_c (string, ' ');
+			g_free (str);
+		}
+		if (pretty)
+			g_string_append_c (string, '\n');
 	}
 	
 	/* selected expressions */
@@ -1492,8 +1465,8 @@ default_render_expr (GdaSqlExpr *expr, GdaSqlRenderingContext *context, gboolean
 	if (is_null)
 		*is_null = FALSE;
 
-	/* can't have:
-	 *  - expr->cast_as && expr->param_spec
+	/* can't have: 
+	 *  - expr->cast_as && expr->param_spec 
 	 */
 	if (!gda_sql_any_part_check_structure (GDA_SQL_ANY_PART (expr), error)) return NULL;
 
@@ -1639,7 +1612,7 @@ default_render_expr (GdaSqlExpr *expr, GdaSqlRenderingContext *context, gboolean
 
 	if (!str) goto err;
 
-	if (expr->cast_as)
+	if (expr->cast_as) 
 		g_string_append_printf (string, "CAST (%s AS %s)", str, expr->cast_as);
 	else
 		g_string_append (string, str);
@@ -1729,11 +1702,7 @@ default_render_function (GdaSqlFunction *func, GdaSqlRenderingContext *context,
 			g_string_append (string, ", ");
 		str = context->render_expr (list->data, context, NULL, NULL, error);
 		if (!str) goto err;
-		if (((GdaSqlExpr*) list->data)->select)
-			g_string_append_c (string, '(');
 		g_string_append (string, str);
-		if (((GdaSqlExpr*) list->data)->select)
-			g_string_append_c (string, ')');
 		g_free (str);
 	}
 	g_string_append_c (string, ')');
@@ -1803,15 +1772,9 @@ default_render_operation (GdaSqlOperation *op, GdaSqlRenderingContext *context,
 	case GDA_SQL_OPERATOR_TYPE_LIKE:
 		str = g_strdup_printf ("%s LIKE %s", SQL_OPERAND (sql_list->data)->sql, SQL_OPERAND (sql_list->next->data)->sql);
 		break;
-	case GDA_SQL_OPERATOR_TYPE_NOTLIKE:
-		str = g_strdup_printf ("%s NOT LIKE %s", SQL_OPERAND (sql_list->data)->sql, SQL_OPERAND (sql_list->next->data)->sql);
-		break;
 	case GDA_SQL_OPERATOR_TYPE_ILIKE:
 		str = g_strdup_printf ("%s ILIKE %s", SQL_OPERAND (sql_list->data)->sql, SQL_OPERAND (sql_list->next->data)->sql);
 		break;
-	case GDA_SQL_OPERATOR_TYPE_NOTILIKE:
-		str = g_strdup_printf ("%s NOT ILIKE %s", SQL_OPERAND (sql_list->data)->sql, SQL_OPERAND (sql_list->next->data)->sql);
-		break;
 	case GDA_SQL_OPERATOR_TYPE_GT:
 		str = g_strdup_printf ("%s > %s", SQL_OPERAND (sql_list->data)->sql, SQL_OPERAND (sql_list->next->data)->sql);
 		break;
