@@ -29,7 +29,6 @@
 #include "gda-capi.h"
 #include "gda-capi-recordset.h"
 #include "gda-capi-provider.h"
-#include <libgda/gda-debug-macros.h>
 
 #define _GDA_PSTMT(x) ((GdaPStmt*)(x))
 
@@ -114,7 +113,7 @@ gda_capi_recordset_get_type (void)
 	static GType type = 0;
 
 	if (G_UNLIKELY (type == 0)) {
-		static GMutex registering;
+		static GStaticMutex registering = G_STATIC_MUTEX_INIT;
 		static const GTypeInfo info = {
 			sizeof (GdaCapiRecordsetClass),
 			(GBaseInitFunc) NULL,
@@ -127,10 +126,10 @@ gda_capi_recordset_get_type (void)
 			(GInstanceInitFunc) gda_capi_recordset_init,
 			0
 		};
-		g_mutex_lock (&registering);
+		g_static_mutex_lock (&registering);
 		if (type == 0)
 			type = g_type_register_static (GDA_TYPE_DATA_SELECT, "GdaCapiRecordset", &info, 0);
-		g_mutex_unlock (&registering);
+		g_static_mutex_unlock (&registering);
 	}
 
 	return type;
