@@ -1,7 +1,6 @@
 /*
- * Copyright (C) 2009 - 2012 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2009 - 2011 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2010 David King <davidk@openismus.com>
- * Copyright (C) 2011 Murray Cumming <murrayc@murrayc.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -169,7 +168,6 @@ update_ad_auth (AuthData *ad)
 			
 			g_strfreev (array);
 		}
-		gdaui_basic_form_entry_grab_focus (GDAUI_BASIC_FORM (ad->auth_widget), NULL);
 	}
 }
 
@@ -316,9 +314,9 @@ sub_thread_open_cnc (AuthData *ad, GError **error)
 	}
 #endif
 	return cnc;
-#else /* DUMMY defined */
+#else
 	sleep (5);
-	g_set_error (error, GDA_TOOLS_ERROR, TOOLS_INTERNAL_COMMAND_ERROR, "%s", "Dummy error!");
+	g_set_error (error, 0, 0, "Oooo");
 	return NULL;
 #endif
 }
@@ -384,23 +382,6 @@ auth_form_activated_cb (G_GNUC_UNUSED GdauiBasicForm *form, AuthDialog *dialog)
 	gtk_dialog_response (GTK_DIALOG (dialog), GTK_RESPONSE_ACCEPT);
 }
 
-static void
-auth_contents_changed_cb (GdauiBasicForm *form, GdaHolder *h, gboolean is_user_modif, AuthDialog *dialog)
-{
-	GSList *list;
-	for (list = dialog->priv->auth_list; list; list = list->next) {
-		AuthData *ad = (AuthData*) list->data;
-		if (! gdaui_basic_form_is_valid (GDAUI_BASIC_FORM (ad->auth_widget)))
-			break;
-	}
-
-	gboolean is_valid;
-	is_valid = list ? FALSE : TRUE;
-	gtk_dialog_set_response_sensitive (GTK_DIALOG (dialog), GTK_RESPONSE_ACCEPT, is_valid);
-        if (is_valid)
-                gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_ACCEPT);
-}
-
 /**
  * auth_dialog_add_cnc_string
  */
@@ -453,7 +434,7 @@ auth_dialog_add_cnc_string (AuthDialog *dialog, const gchar *cnc_string, GError
 	AuthData *ad;
 	ad = g_new0 (AuthData, 1);
 	ad->wrapper = gda_thread_wrapper_new ();
-	/*g_print ("Auth dialog: new thread wrapper %p\n", ad->wrapper);*/
+	/*g_print ("Login dialog: new thread wrapper %p\n", ad->wrapper);*/
 	ad->ext.cnc_string = g_strdup (cnc_string);
 	ad->auth_string = NULL;
 	info = gda_config_get_dsn_info (real_cnc);
@@ -523,8 +504,6 @@ auth_dialog_add_cnc_string (AuthDialog *dialog, const gchar *cnc_string, GError
                 ad->auth_widget = gdaui_basic_form_new (set);
                 g_signal_connect (G_OBJECT (ad->auth_widget), "activated",
 				  G_CALLBACK (auth_form_activated_cb), dialog);
-                g_signal_connect (G_OBJECT (ad->auth_widget), "holder-changed",
-				  G_CALLBACK (auth_contents_changed_cb), dialog);
                 g_object_unref (set);
 
 		/* add widget */
@@ -727,6 +706,7 @@ auth_dialog_run (AuthDialog *dialog)
 	}
 
  out:
+	gtk_widget_hide (GTK_WIDGET (dialog));
 	return allopened;
 }
 
