@@ -19,15 +19,8 @@
 
 #include "browser-page.h"
 #include "browser-perspective.h"
-#if GLIB_CHECK_VERSION(2,31,7)
-static GRecMutex init_rmutex;
-#define MUTEX_LOCK() g_rec_mutex_lock(&init_rmutex)
-#define MUTEX_UNLOCK() g_rec_mutex_unlock(&init_rmutex)
-#else
+
 static GStaticRecMutex init_mutex = G_STATIC_REC_MUTEX_INIT;
-#define MUTEX_LOCK() g_static_rec_mutex_lock(&init_mutex)
-#define MUTEX_UNLOCK() g_static_rec_mutex_unlock(&init_mutex)
-#endif
 static void browser_page_class_init (gpointer g_class);
 
 GType
@@ -49,12 +42,12 @@ browser_page_get_type (void)
 			0
 		};
 		
-		MUTEX_LOCK();
+		g_static_rec_mutex_lock (&init_mutex);
 		if (type == 0) {
 			type = g_type_register_static (G_TYPE_INTERFACE, "BrowserPage", &info, 0);
 			g_type_interface_add_prerequisite (type, GTK_TYPE_WIDGET);
 		}
-		MUTEX_UNLOCK();
+		g_static_rec_mutex_unlock (&init_mutex);
 	}
 	return type;
 }
@@ -64,11 +57,11 @@ browser_page_class_init (G_GNUC_UNUSED gpointer g_class)
 {
 	static gboolean initialized = FALSE;
 
-	MUTEX_LOCK();
+	g_static_rec_mutex_lock (&init_mutex);
 	if (! initialized) {
 		initialized = TRUE;
 	}
-	MUTEX_UNLOCK();
+	g_static_rec_mutex_unlock (&init_mutex);
 }
 
 /**
