@@ -1,10 +1,10 @@
 /*
- * Copyright (C) 2010 - 2011 Vivien Malerba
+ * Copyright (C) 2010 - 2011 Vivien Malerba <malerba@gnome-db.org>
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -13,8 +13,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
- * USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #ifndef __UI_FORMGRID__
@@ -41,7 +40,7 @@ typedef struct _UiFormGridPriv  UiFormGridPriv;
 /* struct for the object's data */
 struct _UiFormGrid
 {
-	GtkVBox             object;
+	GtkBox             object;
 
 	UiFormGridPriv     *priv;
 };
@@ -49,7 +48,9 @@ struct _UiFormGrid
 /* struct for the object's class */
 struct _UiFormGridClass
 {
-	GtkVBoxClass       parent_class;
+	GtkBoxClass       parent_class;
+	/* signals */
+	void             (*data_set_changed) (UiFormGrid *fg);
 };
 
 /**
@@ -74,6 +75,7 @@ void              ui_formgrid_set_sample_size     (UiFormGrid *formgrid, gint sa
 GdauiRawGrid     *ui_formgrid_get_grid_widget     (UiFormGrid *formgrid);
 
 void              ui_formgrid_set_connection      (UiFormGrid *formgrid, BrowserConnection *bcnc);
+GtkUIManager     *ui_formgrid_get_ui_manager      (UiFormGrid *formgrid);
 
 G_END_DECLS
 
