@@ -1,7 +1,6 @@
 /*
- * Copyright (C) 2009 - 2012 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2009 - 2011 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2010 David King <davidk@openismus.com>
- * Copyright (C) 2011 Murray Cumming <murrayc@murrayc.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -26,7 +25,6 @@
 #include <libgda-ui/libgda-ui.h>
 #include <libgda-ui/gdaui-plugin.h>
 #include "common/gdaui-entry-import.h"
-#include "../tool-utils.h"
 
 /* 
  * Main static functions 
@@ -42,7 +40,7 @@ static void update_display (ConnectionBindingProperties *cprop);
 struct _ConnectionBindingPropertiesPrivate
 {
 	BrowserVirtualConnectionSpecs *specs;
-	GtkGrid     *layout_grid;
+	GtkTable    *layout_table;
 	GtkWidget   *menu;
 };
 
@@ -228,8 +226,8 @@ create_layout (ConnectionBindingProperties *cprop)
 	label = gtk_label_new ("      ");
 	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 
-	cprop->priv->layout_grid = GTK_GRID (gtk_grid_new ());
-	gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (cprop->priv->layout_grid), TRUE, TRUE, 0);
+	cprop->priv->layout_table = GTK_TABLE (gtk_table_new (2, 2, FALSE));
+	gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (cprop->priv->layout_table), TRUE, TRUE, 0);
 
 	gtk_widget_show_all (dcontents);
 
@@ -247,7 +245,7 @@ static void
 update_display (ConnectionBindingProperties *cprop)
 {
 	/* clear any previous setting */
-	gtk_container_foreach (GTK_CONTAINER (cprop->priv->layout_grid), (GtkCallback) gtk_widget_destroy, NULL);
+	gtk_container_foreach (GTK_CONTAINER (cprop->priv->layout_table), (GtkCallback) gtk_widget_destroy, NULL);
 
 	/* new contents */
 	gint top = 0;
@@ -270,7 +268,8 @@ update_display (ConnectionBindingProperties *cprop)
 				g_assert_not_reached ();
 			}
 
-			gtk_grid_attach (cprop->priv->layout_grid, display, 0, top, 1, 1);
+			gtk_table_attach (cprop->priv->layout_table, display, 0, 1, top, top + 1,
+					  GTK_EXPAND | GTK_FILL, 0, 0, 10);
 		}
 	}
 
@@ -282,11 +281,11 @@ update_display (ConnectionBindingProperties *cprop)
 	arrow = gtk_arrow_new (GTK_ARROW_RIGHT, GTK_SHADOW_NONE);
 	gtk_box_pack_start (GTK_BOX (label), arrow, FALSE, FALSE, 0);
 	g_object_set (G_OBJECT (button), "relief", GTK_RELIEF_NONE, NULL);
-	gtk_grid_attach (cprop->priv->layout_grid, button, 0, top, 2, 1);
+	gtk_table_attach (cprop->priv->layout_table, button, 0, 2, top, top + 1, GTK_EXPAND | GTK_FILL, 0, 0, 10);
 	g_signal_connect (button, "clicked",
 			  G_CALLBACK (add_part_clicked_cb), cprop);
 	
-	gtk_widget_show_all ((GtkWidget*) cprop->priv->layout_grid);
+	gtk_widget_show_all ((GtkWidget*) cprop->priv->layout_table);
 
 	update_buttons_sensitiveness (cprop);
 }
@@ -472,8 +471,8 @@ part_for_cnc_validate_holder_change_cb (G_GNUC_UNUSED GdaSet *set, GdaHolder *ho
 			if (((ptr == str) && ! g_ascii_isalpha (*ptr)) ||
 			    ((ptr != str) && (*ptr != '_') && !g_ascii_isalnum (*ptr))) {
 				GError *error = NULL;
-				g_set_error (&error, GDA_TOOLS_ERROR, GDA_TOOLS_COMMAND_ARGUMENTS_ERROR,
-					     "%s", _("Invalid schema name"));
+				g_set_error (&error, 0, 0,
+					     _("Invalid schema name"));
 				return error;
 			}
 		}
