@@ -43,7 +43,7 @@ struct _QueryFavoriteSelectorClass {
 	GtkBoxClass          parent_class;
 
 	void                (*selection_changed) (QueryFavoriteSelector *sel, gint fav_id,
-						  ToolsFavoritesType fav_type, const gchar *fav_contents);
+						  BrowserFavoritesType fav_type, const gchar *fav_contents);
 };
 
 GType                    query_favorite_selector_get_type (void) G_GNUC_CONST;
